"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var NgLocalStorage = /** @class */ (function () {
    /**
     * @constructor
     */
    function NgLocalStorage() {
        this.appName = "NG-LOCALSTORAGE";
        this.noSupportMessage = "[" + this.appName + "]: HTML5 localStorage not supported in this Browser!";
        this.objectProperties = [];
        this.hasSublevel = false;
        this.hasStorageSupport = true;
        if (!this.__supportsLocalStorage()) {
            this.hasStorageSupport = false;
            console.warn(this.noSupportMessage);
        }
    }
    /**
     * localStorage `getItem` method
     * @param {string} props - Dot separated string - dot notation to access property values
     */
    NgLocalStorage.prototype.get = function (props) {
        if (!this.hasStorageSupport) {
            console.warn(this.noSupportMessage);
        }
        var objectName = this.__extractObjectName(props);
        var objectValue = localStorage.getItem(objectName);
        if (!objectValue) {
            console.warn("Item \"" + objectName + "\" does not exists in localStorage. Please verify item.");
            return undefined;
        }
        var parsedData = this.__tryParse(objectValue);
        if (parsedData.valid) {
            return this.__getPropertyData(parsedData.value, this.objectProperties.join('.'));
        }
        else {
            return objectValue;
        }
    };
    /**
     * localStorage `setItem` method
     * @param {string} key - Item / key where the value will be stored
     * @param {any} value - Value to be stored; Whether a String or an Object
     */
    NgLocalStorage.prototype.set = function (key, value) {
        if (!this.hasStorageSupport) {
            console.warn(this.noSupportMessage);
        }
        try {
            localStorage.setItem(key, typeof (value) === "object" ? JSON.stringify(value) : value);
        }
        catch (e) {
            console.warn("[" + this.appName + "]: " + e);
        }
    };
    /**
     * localStorage `remove` method
     * @param {string} key - Item key to be removed from localStorage
     */
    NgLocalStorage.prototype.remove = function (key) {
        if (!this.hasStorageSupport) {
            console.warn(this.noSupportMessage);
        }
        try {
            localStorage.removeItem(key);
        }
        catch (e) {
            console.warn("[" + this.appName + "]: " + e);
        }
    };
    /**
     * localStorage `clear` method
     */
    NgLocalStorage.prototype.clear = function () {
        if (!this.hasStorageSupport) {
            console.warn(this.noSupportMessage);
        }
        try {
            localStorage.clear();
        }
        catch (e) {
            console.warn("[" + this.appName + "]: " + e);
        }
    };
    /**
     * Used to extract Object from giving dot-notation string
     * @param {string} props - Dot separated string - dot notation to access property values
     */
    NgLocalStorage.prototype.__extractObjectName = function (props) {
        var parts = props.split('.');
        this.objectProperties = parts.splice(1);
        this.hasSublevel = this.objectProperties.length == 0 ? false : true;
        return parts[0];
    };
    /**
     * Recursive method to get property value based on dot-notation string input
     * @param {object} obj - Object to be searched
     * @param {string} props - Dot separated string - dot notation to access property values
     */
    NgLocalStorage.prototype.__getPropertyData = function (obj, props) {
        if (!props)
            return obj;
        var propsArr = props.split('.');
        var prop = propsArr.splice(0, 1);
        return this.__getPropertyData(obj[prop], propsArr.join('.'));
    };
    /**
     * Used to catch possible errors in parsing data
     * @param {any} data - Value retrieved from localStorage data
     */
    NgLocalStorage.prototype.__tryParse = function (data) {
        try {
            return { value: JSON.parse(data), valid: true };
        }
        catch (e) {
            return { value: data, valid: false };
        }
    };
    /**
     * Used to check localStorage support
     */
    NgLocalStorage.prototype.__supportsLocalStorage = function () {
        return typeof (Storage) !== 'undefined';
    };
    NgLocalStorage = __decorate([
        core_1.Injectable(),
        __metadata("design:paramtypes", [])
    ], NgLocalStorage);
    return NgLocalStorage;
}());
exports.NgLocalStorage = NgLocalStorage;
//# sourceMappingURL=ng-localstorage.js.map